@@ -33,6 +33,7 @@
  *  \brief Crea un arreglo de células de tipo PdsCellString con N elementos 
  *  vacíos (NULL).
  *  \param[in] N Número de elementos de elementos del arreglo de células.
+ *  N puede ser cero.
  *  \return Un puntero a una estructura de tipo PdsCellString.
  *  \ingroup PdsCellStringGroup
  */
@@ -119,7 +120,7 @@ PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin)
  *  \param[in,out] C El arreglo de células a escribir.
  *  \param[in] id Posición en donde escribir el dato.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Retorna FALSE si el id está fuera 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Retorna PDS_WRONG si el id está fuera 
  *  de rango.
  *  \ingroup PdsCellStringGroup
  */
@@ -127,18 +128,18 @@ int pds_cell_string_write(PdsCellString *C,int id,const char* string_data)
 {
     char *tmp=NULL;
 
-	if(C==NULL)		return FALSE;
+	if(C==NULL)		return PDS_WRONG;
 
-    if( (id>=C->Ncell)||(id<0) )    return FALSE;
+    if( (id>=C->Ncell)||(id<0) )    return PDS_WRONG;
     
     tmp=(char *)calloc(strlen(string_data)+1,sizeof(char));
-    if(tmp==NULL)   FALSE;
+    if(tmp==NULL)   return PDS_WRONG;
     sprintf(tmp,"%s",string_data);
 
     free(C->data[id]);
     C->data[id]=tmp;
 
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -146,20 +147,20 @@ int pds_cell_string_write(PdsCellString *C,int id,const char* string_data)
  *  \brief Imprime en pantalla los datos del arreglo de células de tipo puntero 
  *  PdsCellString. Escribe un dato por cada linea.
  *  \param[in] C El arreglo de células a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_all_printf(const PdsCellString *C)
 {
     int i;
-	if(C==NULL)		return FALSE;
+	if(C==NULL)		return PDS_WRONG;
 
     for(i=0;i<C->Ncell;i++)
     {
 	    printf("%s\n",C->data[i]);
     }
 	
-	return TRUE;
+	return PDS_OK;
 }
 
 
@@ -168,21 +169,21 @@ int pds_cell_string_all_printf(const PdsCellString *C)
  *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
  *  \param[in,out] fd El descriptor de fichero sobre el cual escribir.
  *  \param[in] C El arreglo de células a escribir.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C)
 {
     int i;
-	if(C==NULL)     return FALSE;
-	if(fd==NULL)	return FALSE;
+	if(C==NULL)     return PDS_WRONG;
+	if(fd==NULL)	return PDS_WRONG;
 
     for(i=0;i<C->Ncell;i++)
     {
 	    fprintf(fd,"%s\n",C->data[i]);
     }
 	
-	return TRUE;
+	return PDS_OK;
 }
 
 /** \fn int pds_cell_string_save(const char* pathname,const PdsCellString *C)
@@ -190,7 +191,7 @@ int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C)
  *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
  *  \param[in] pathname La dirección de fichero sobre el cual escribir.
  *  \param[in] C El arreglo de células a escribir.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_save(const char* pathname,const PdsCellString *C)
@@ -198,11 +199,11 @@ int pds_cell_string_save(const char* pathname,const PdsCellString *C)
     int i;
     FILE *fd=NULL;
 
-	if(C==NULL)		    return FALSE;
-	if(pathname==NULL)  return FALSE;
+	if(C==NULL)		    return PDS_WRONG;
+	if(pathname==NULL)  return PDS_WRONG;
 
     fd=fopen(pathname,"w");
-    if(fd==NULL)    return FALSE;
+    if(fd==NULL)    return PDS_WRONG;
 
     for(i=0;i<C->Ncell;i++)
     {
@@ -210,7 +211,7 @@ int pds_cell_string_save(const char* pathname,const PdsCellString *C)
     }
 
     fclose(fd);
-	return TRUE;
+	return PDS_OK;
 }
 
 
@@ -261,27 +262,27 @@ void pds_cell_string_destroy(PdsCellString **C)
  *  O agrega un nuevo registro de memoria.
  *  \param[in,out] C El arreglo de células para agregar datos.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Si string_data==NULL 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si string_data==NULL 
  *  no es considerado error y se finaliza la función sin hacer ningún cambio.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_add(PdsCellString *C,const char* string_data)
 {
-    int i,id,dat=TRUE;
+    int i,id,dat=PDS_OK;
     char **temp=NULL;
 
-	if(C==NULL)             return FALSE;
-	if(string_data==NULL)   return TRUE;
+	if(C==NULL)             return PDS_WRONG;
+	if(string_data==NULL)   return PDS_OK;
 
     id=pds_cell_string_get_last_empty(C);
 
-    if(id<0)        return FALSE;
-    if(id>C->Ncell) return FALSE;
+    if(id<0)        return PDS_WRONG;
+    if(id>C->Ncell) return PDS_WRONG;
 
     if(id==C->Ncell)
     {
         temp=(char **)calloc(C->Ncell+2,sizeof(char*));
-        if(temp==NULL)   return FALSE;
+        if(temp==NULL)   return PDS_WRONG;
 
         for(i=0;i<=C->Ncell;i++)    temp[i]=C->data[i];
         temp[C->Ncell+1]=NULL;
@@ -290,7 +291,7 @@ int pds_cell_string_add(PdsCellString *C,const char* string_data)
         if(temp[C->Ncell]==NULL)
         {
             free(temp);
-            return FALSE;
+            return PDS_WRONG;
         }
         sprintf(temp[C->Ncell],"%s",string_data);
 
@@ -318,7 +319,7 @@ int pds_cell_string_add(PdsCellString *C,const char* string_data)
  *  NO LIBERAR Y RESERVAR MEMORIA TAN ALEGREMENTE. ASSI SE GANARIA VELOCIDAD.
  *  \param[in,out] C El arreglo de células a agregar datos.
  *  \param[in] Cin El arreglo de células de donde se leen los datos.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin)
@@ -326,18 +327,18 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin)
     int i,dat;
     PdsCellString *Ctmp=NULL;
 
-	if(C==NULL)       return FALSE;
-	if(Cin==NULL)     return TRUE;
+	if(C==NULL)       return PDS_WRONG;
+	if(Cin==NULL)     return PDS_OK;
 
     Ctmp=pds_cell_string_new_copy(C);
 
     for(i=0;i<Cin->Ncell;i++)
     {
         dat=pds_cell_string_add(Ctmp,Cin->data[i]);
-        if(dat==FALSE)  
+        if(dat==PDS_WRONG)  
         {
             pds_cell_string_free(Ctmp);
-            return FALSE;
+            return PDS_WRONG;
         }
     }
 
@@ -346,7 +347,7 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin)
     C->Ncell=Ctmp->Ncell;
     free(Ctmp);
 
-    return TRUE;
+    return PDS_OK;
 }
 
 /** \fn int pds_cell_string_read(const PdsCellString* C,int id,char** string_data)
@@ -355,23 +356,90 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin)
  *  \param[in] id La posición a leer.
  *  \param[out] string_data La dirección de la cadena a leer (NO debe liberarse esta 
  *  dirección de memoria).
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_read(const PdsCellString* C,int id,char** string_data)
 {
-    char *tmp=NULL;
 
-	if(C==NULL)		                return FALSE;
-	if(string_data==NULL)           return FALSE;
-    if( (id>=C->Ncell)||(id<0) )    return FALSE;
+	if(C==NULL)		                return PDS_WRONG;
+	if(string_data==NULL)           return PDS_WRONG;
+    if( (id>=C->Ncell)||(id<0) )    return PDS_WRONG;
 
     (*string_data)=C->data[id];
 
-    return TRUE;
+    return PDS_OK;
 }
 
+/** \fn int pds_cell_string_sort_by_length( PdsCellString *C)
+ *  \brief Ordena de forma alfabetica ascendentemente con los siguientes criterios:
+ *  es mayor quien tienes mas carateres, si son igual numero de caracteres
+ *  entonces es mayor quien tiene  mas orden alfabetico.
+ *  \param[in] C El arreglo de células a ordenar.
+ *  \return Retorna un número menor que cero en caso de error.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_sort_by_length( PdsCellString *C)
+{
+    int i,j;
+    char *tmp;
 
+	if(C==NULL) return -1;
+	if(C->Ncell<=1) return 0;
+
+    for(j=0;j<(C->Ncell-1);j++)
+    for(i=1;i<(C->Ncell-j);i++)
+    {
+        
+        if( strlen(C->data[i-1])>strlen(C->data[i]) )
+        {
+            tmp=C->data[i-1];
+            C->data[i-1]=C->data[i];
+            C->data[i]=tmp;
+        }
+        else 
+        if( strlen(C->data[i-1])==strlen(C->data[i]) )
+        {
+            if( strcmp(C->data[i-1],C->data[i])>0 )
+            {
+                tmp=C->data[i-1];
+                C->data[i-1]=C->data[i];
+                C->data[i]=tmp;
+            }
+        }
+    }
+
+	return 0;
+}
+
+/** \fn int pds_cell_string_sort_by_lexicographic_order( PdsCellString *C)
+ *  \brief Ordena de forma lexicografica ascendentemente las celulas.
+ *  \param[in] C El arreglo de células a ordenar.
+ *  \return Retorna un número menor que cero en caso de error.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_sort_by_lexicographic_order( PdsCellString *C)
+{
+    int i,j;
+    char *tmp;
+
+	if(C==NULL) return -1;
+	if(C->Ncell<=1) return 0;
+
+    for(j=0;j<(C->Ncell-1);j++)
+    for(i=1;i<(C->Ncell-j);i++)
+    {
+        if( pds_strlexcmp(C->data[i-1],C->data[i])>0 )
+        {
+            tmp=C->data[i-1];
+            C->data[i-1]=C->data[i];
+            C->data[i]=tmp;
+        }    
+
+    }
+
+	return 0;
+}
 
 /** \fn int pds_cell_string_get_ncell(const PdsCellString *C)
  *  \brief Cuenta la cantidad de células incluyendo las vacías.
@@ -552,7 +620,7 @@ PdsCellString *pds_cell_string_new_load(const char*filepath)
 {
 	PdsCellString *C=NULL;
     char *line;
-    int dat,i;
+    int dat;
     FILE *fd=NULL;
 
     if (filepath==NULL)         return NULL;
@@ -570,8 +638,13 @@ PdsCellString *pds_cell_string_new_load(const char*filepath)
 
     do{
         line=pds_read_line(fd);
-        dat=pds_cell_string_add(C,line);
-        free(line);
+        if(line==NULL)   fprintf(stderr,"ERROR: Reading string from file:%s\n",filepath);
+        else
+        {
+            dat=pds_cell_string_add(C,line);
+            if(dat==PDS_WRONG)   fprintf(stderr,"ERROR: Adding values to the PdsCellString\n");
+            free(line);
+        }
     }while(feof(fd)==0);
 
     fclose(fd);
@@ -586,7 +659,7 @@ PdsCellString *pds_cell_string_new_load(const char*filepath)
  *
  *  \param[in,out] C El arreglo de células a remover datos.
  *  \param[in] id El id de la célula a remover.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  En caso de error no modifica el contenido de C.
  *  \ingroup PdsCellStringGroup
  */
@@ -595,12 +668,12 @@ int pds_cell_string_remove(PdsCellString *C,int id)
     int i;
     char **data=NULL;
 
-	if(C==NULL)         return FALSE;
-	if(id<0)            return FALSE;
-	if(id>=C->Ncell)    return FALSE;
+	if(C==NULL)         return PDS_WRONG;
+	if(id<0)            return PDS_WRONG;
+	if(id>=C->Ncell)    return PDS_WRONG;
 
     data=(char**)calloc(C->Ncell,sizeof(char*));
-    if(data==NULL)  return FALSE;
+    if(data==NULL)  return PDS_WRONG;
     
     for(i=0;i<id;i++)   data[i]=C->data[i];
 
@@ -613,7 +686,7 @@ int pds_cell_string_remove(PdsCellString *C,int id)
     free(C->data);
     C->data=data;
 
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -624,9 +697,9 @@ int pds_cell_string_remove(PdsCellString *C,int id)
  *  \param[in,out] C El arreglo de células a remover datos.
  *  \param[in] pattern El patrón de búsqueda.Ejemplo: pattern->data[i] <-- "*.[ch]"
  *  donde se aceptarán "*.c" o "*.h". La función cumple patrones aceptados por fnmatch().
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  En caso de error el contenido de C no es modificado. Si pattern es NULL no 
- *  es considerado error y se retorn TRUE sin hacer nada.
+ *  es considerado error y se retorn PDS_OK sin hacer nada.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
@@ -634,29 +707,29 @@ int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
     PdsCellString *C0=NULL;
     int i,j,dat,fulfill_any_pattern;
 
-    if(C==NULL)         return  FALSE;
-    if(pattern==NULL)   return  TRUE;
+    if(C==NULL)         return  PDS_WRONG;
+    if(pattern==NULL)   return  PDS_OK;
 
     C0=pds_cell_string_new_copy(C);
-    if(C0==NULL)    return FALSE;
+    if(C0==NULL)    return PDS_WRONG;
     
 
     for(i=0;i<C0->Ncell;i++)
     {
-        fulfill_any_pattern=FALSE;
+        fulfill_any_pattern=PDS_WRONG;
         for(j=0;j<pattern->Ncell;j++)
         {
             if(pds_fnmatch(pattern->data[j], C0->data[i], FNM_NOESCAPE)==0)
             {
-                fulfill_any_pattern=TRUE;
+                fulfill_any_pattern=PDS_OK;
                 break;
             }
         }
 
-        if(fulfill_any_pattern==FALSE)
+        if(fulfill_any_pattern==PDS_WRONG)
         {
             dat=pds_cell_string_remove(C0,i);
-            if(dat==FALSE)  return FALSE;
+            if(dat==PDS_WRONG)  return PDS_WRONG;
 
             i=i-1;
         }
@@ -671,7 +744,7 @@ int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
     C->Ncell=C0->Ncell;
     free(C0);
 
-    return TRUE;
+    return PDS_OK;
     
 }
 
@@ -682,7 +755,7 @@ int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
  *  diferencia mayúsculas y minúsculas.
  *  \param[in,out] C El arreglo de células para agregar datos.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Si string_data==NULL 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si string_data==NULL 
  *  no es considerado error y se finaliza la función sin hacer ningún cambio.
  *  \ingroup PdsCellStringGroup
  */
@@ -690,9 +763,9 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
 {
     int i,id=-1;
     int dat;
-    int RET=TRUE;
-	if(C==NULL)		                return FALSE;
-	if(string_data==NULL)           return TRUE;
+    int RET=PDS_OK;
+	if(C==NULL)		                return PDS_WRONG;
+	if(string_data==NULL)           return PDS_OK;
 
     for(i=0;i<C->Ncell;i++)
     {
@@ -700,10 +773,10 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
         {
             id=i;
             dat=pds_cell_string_write(C,i,string_data);
-            if(dat==FALSE)
+            if(dat==PDS_WRONG)
             {
                 fprintf(stderr,"ERROR writing the data[%d]=%s",id,string_data);
-                RET=FALSE;
+                RET=PDS_WRONG;
             }
         }
     }
@@ -711,10 +784,10 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
     if(id==-1)
     {
         dat=pds_cell_string_add(C,string_data);
-        if(dat==FALSE)
+        if(dat==PDS_WRONG)
         {
             fprintf(stderr,"ERROR adding the data=%s",string_data);
-            return FALSE;
+            return PDS_WRONG;
         }
     }
 
@@ -726,8 +799,8 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
  *  \brief Procura todas las células con cadenas igual a str y las remueve.
  *  \param[in,out] C El arreglo de células a analizar.
  *  \param[in] str La cadena a buscar.
- *  \return Retorna TRUE si todo fue bien o FALSE si no. Si C o str son nulos
- *  entonces retorna FALSE sin hacer nada sobre C.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no. Si C o str son nulos
+ *  entonces retorna PDS_WRONG sin hacer nada sobre C.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_find_and_remove(PdsCellString *C,const char *str)
@@ -735,24 +808,24 @@ int pds_cell_string_find_and_remove(PdsCellString *C,const char *str)
     int id;
     int dat;
 
-    if(C==NULL)     return FALSE;
-    if(str==NULL)   return FALSE;
+    if(C==NULL)     return PDS_WRONG;
+    if(str==NULL)   return PDS_WRONG;
 
     do{
         id=pds_cell_string_find(C,str);
         if(id>=0)
         {
             dat=pds_cell_string_remove(C,id);
-            if(dat==FALSE)
+            if(dat==PDS_WRONG)
             {
                 fprintf(stderr,"ERROR removing the data[%d]=%s",id,str);
                 fprintf(stderr,"Trying newly ...");
-                //return FALSE;
+                //return PDS_WRONG;
             }
         }
     }while(id>=0);
 
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -761,8 +834,8 @@ int pds_cell_string_find_and_remove(PdsCellString *C,const char *str)
  *  \param[in,out] C El arreglo de células a analizar.
  *  La función es case-insensitive.
  *  \param[in] str La cadena a buscar.
- *  \return Retorna TRUE si todo fue bien o FALSE si no. Si C o str son nulos
- *  entonces retorna FALSE sin hacer nada sobre C.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no. Si C o str son nulos
+ *  entonces retorna PDS_WRONG sin hacer nada sobre C.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_findci_and_remove(PdsCellString *C,const char *str)
@@ -770,23 +843,23 @@ int pds_cell_string_findci_and_remove(PdsCellString *C,const char *str)
     int id;
     int dat;
 
-    if(C==NULL)     return FALSE;
-    if(str==NULL)   return FALSE;
+    if(C==NULL)     return PDS_WRONG;
+    if(str==NULL)   return PDS_WRONG;
 
     do{
         id=pds_cell_string_findci(C,str);
         if(id>=0)
         {
             dat=pds_cell_string_remove(C,id);
-            if(dat==FALSE)
+            if(dat==PDS_WRONG)
             {
                 fprintf(stderr,"ERROR removing the data[%d]=%s",id,str);
                 fprintf(stderr,"Trying newly ...");
-                //return FALSE;
+                //return PDS_WRONG;
             }
         }
     }while(id>=0);
 
-    return TRUE;
+    return PDS_OK;
 }
 
