@@ -37,6 +37,8 @@
 
 #include <time.h>
 
+#include <errno.h>
+
 #define __BUFFER_SIZE__ 4096
 #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
     #include <windows.h>
@@ -183,6 +185,8 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
 char *pds_get_homedir(void)
 {
     char homedir[__BUFFER_SIZE__];
+    memset(homedir, 0,__BUFFER_SIZE__);
+
     #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
     snprintf(homedir, __BUFFER_SIZE__, "%s%s", getenv("HOMEDRIVE"), getenv("HOMEPATH"));
     #elif defined(__linux__)
@@ -258,14 +262,14 @@ PdsCellString *pds_get_all_subdirs_new(const char *dirpath,const char* pattern_i
     if(dir_path==NULL)    return NULL;
 
     dat=pds_cell_string_add(Ca,dir_path);
-    if(dat==FALSE)  {   free(dir_path);
+    if(dat==PDS_WRONG)  {   free(dir_path);
                         pds_cell_string_free(Ca);
                         pds_cell_string_free(C0);
                         return NULL;}
 
 
     dat=pds_cell_string_add_cell_string(C0,Ca);
-    if(dat==FALSE)  {   free(dir_path);
+    if(dat==PDS_WRONG)  {   free(dir_path);
                         pds_cell_string_free(Ca);
                         pds_cell_string_free(C0);
                         return NULL;}
@@ -278,7 +282,7 @@ PdsCellString *pds_get_all_subdirs_new(const char *dirpath,const char* pattern_i
         //printf("____________\n");
 
         dat=pds_cell_string_add_cell_string(C0,Cb);
-        if(dat==FALSE)  {   free(dir_path);
+        if(dat==PDS_WRONG)  {   free(dir_path);
                             pds_cell_string_free(Ca);
                             pds_cell_string_free(Cb);
                             pds_cell_string_free(C0);
@@ -326,7 +330,7 @@ PdsCellString *pds_get_subdirs_new(const PdsCellString *C0,const char* pattern_i
     {
         Ctmp=pds_get_arquives_new(C0->data[i],TYPE_DIR,pattern_include,pattern_exclude);
         dat=pds_cell_string_add_cell_string(Cout,Ctmp);
-        if(dat==FALSE)
+        if(dat==PDS_WRONG)
         {
             pds_cell_string_free(Ctmp);
             pds_cell_string_free(Cout);
@@ -385,7 +389,7 @@ PdsCellString *pds_get_all_files_new(const char *dirpath,   const char* pattern_
                                             file_pattern_include,
                                             file_pattern_exclude);
         dat=pds_cell_string_add_cell_string(FileCell,TmpFileCell);
-        if(dat==FALSE)
+        if(dat==PDS_WRONG)
         {
             pds_cell_string_free(FileCell);
             pds_cell_string_free(TmpFileCell);
@@ -412,7 +416,7 @@ PdsCellString *pds_get_all_files_new(const char *dirpath,   const char* pattern_
  *   filepath.
  *
  *  \param[in] filepath Ruta del fichero a analizar. 
- *  \return Retorna TRUE si todo fue bien o FALSE en el caso contrario.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG en el caso contrario.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_cat(const char* filepath)
@@ -421,13 +425,13 @@ int pds_cat(const char* filepath)
     char c;
 
     fd=fopen(filepath,"r");
-    if(fd==NULL)    return FALSE;
+    if(fd==NULL)    return PDS_WRONG;
 
     while ((c = getc(fd)) != EOF)   putchar(c);
 
     fclose(fd);
 
-    return TRUE;
+    return PDS_OK;
 }
 
 /** \fn char *pds_get_realpath(const char* filepath)
@@ -453,20 +457,21 @@ char *pds_get_realpath(const char* filepath)
     char *file_path=NULL;
 
     #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
-    int i;
-    TCHAR  buffer[__BUFFER_SIZE__]=TEXT(""); 
-    DWORD retval = GetFullPathName(filepath,__BUFFER_SIZE__,buffer,NULL);
-    file_path=(char*)calloc(strlen(buffer)+1,sizeof(char));
-    for(i=0;i<strlen(buffer);i++)
-    {
-        wchar_t wc = buffer[i];
-        char c = (char)wc;
-        file_path[i] = c;
-    }
+        int i;
+        TCHAR  buffer[__BUFFER_SIZE__]=TEXT(""); 
+        DWORD retval = GetFullPathName(filepath,__BUFFER_SIZE__,buffer,NULL);
+        file_path=(char*)calloc(strlen(buffer)+1,sizeof(char));
+        for(i=0;i<strlen(buffer);i++)
+        {
+            wchar_t wc = buffer[i];
+            char c = (char)wc;
+            file_path[i] = c;
+        }
     #elif defined(__linux__)
-    file_path=realpath(filepath,NULL);
+        file_path=realpath(filepath,NULL);
     #else
-    file_path=realpath(filepath,NULL);
+        file_path=realpath(filepath,NULL);
+        
     #endif
 
     return file_path;
@@ -713,6 +718,7 @@ char *pds_get_temporal_filepath(const char *filepath,const char *groupname)
 char* pds_get_absolute_dirname(void)
 {
     char exepath[__BUFFER_SIZE__];
+    memset(exepath, 0,__BUFFER_SIZE__);
 
     #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
         int i;
@@ -751,6 +757,7 @@ char* pds_get_absolute_dirname(void)
 char* pds_get_absolute_programpath(void)
 {
     char exepath[__BUFFER_SIZE__];
+    memset(exepath, 0,__BUFFER_SIZE__);
 
     #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
         int i;
@@ -766,7 +773,7 @@ char* pds_get_absolute_programpath(void)
         int ID=readlink("/proc/self/exe", exepath,__BUFFER_SIZE__-1);
         ID++;
     #else
-        printf("The function pds_get_absolute_dirname() is not suported in this operating system.")
+        printf("The function pds_get_absolute_programpath() is not suported in this operating system.")
         exepath[0]='.'
     #endif
 
@@ -810,7 +817,7 @@ PdsCellString *pds_get_all_filename_extensions_in_cell(const PdsCellString *File
         if(pds_cell_string_find(ExtCell,strPtr)<0)
         {
             dat=pds_cell_string_add(ExtCell,strPtr);
-            if(dat==FALSE)
+            if(dat==PDS_WRONG)
             {
                 pds_cell_string_free(ExtCell);
                 return NULL;
@@ -843,8 +850,6 @@ PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char
 {
     PdsCellString *ExtCell=NULL;
     PdsCellString *FileCell=NULL;
-    char *strPtr=NULL;
-    int i,dat;
 
     if(dirpath==NULL)   return NULL;
 
@@ -962,20 +967,43 @@ char *pds_read_line(FILE *fd)
     return data;
 }
 
-/** \fn char *pds_get_filedata_string(const char *pathname,const char* pattern)
+/** \fn char *pds_get_filedata_string(const char *filepath,const char* pattern, const char* reject,const char* default_value)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el texto despues de el primer patrón pattern encontrado.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  el texto despues del primer patrón pattern encontrado.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer la cadena "Cadena de texto" usaremos:
+ * \code{.c}
+ * DATA=pds_get_filedata_string("mydata.ini","MY_SECOND_DATA","= ","valor por defecto");
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna NULL.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna NULL.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  Si la variable default_value es usada entonces reject no es aplicado sobre el dato retornado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia.
+ *  Si default_value==NULL y no es encontrado ningun dato o este esta vacio entonces
+ *  NULL es retornando.
  *  \return Retorna una nueva cadena de texto con el dato encontrado,
- *  una cadena vacia si no existe ningun dato o NULL
- *  si se encontró algun error.
+ *  o NULL si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-char *pds_get_filedata_string(const char *pathname,const char* pattern)
+char *pds_get_filedata_string(const char *filepath,const char* pattern, const char* reject,const char* default_value)
 {
     FILE *fd=NULL;
     char *LINE=NULL;
@@ -983,23 +1011,31 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
     int N,Nl,i;
     char *PATTERN=NULL;
 
-    if(pathname==NULL)  return NULL;
-    if(pattern ==NULL)  return NULL;
+    if(filepath==NULL)
+    {
+        //fprintf(stdout,"WARNING(pds_get_filedata_string): First parameter equal to NULL.\n")
+        return NULL;
+    }
+    if(pattern ==NULL)
+    {
+        //fprintf(stdout,"WARNING(pds_get_filedata_string): Second parameter equal to NULL.\n")
+        return NULL;
+    }
 
 
     PATTERN=(char*)calloc(strlen(pattern)+1,sizeof(char));
     if(PATTERN==NULL)   return NULL;
     strcpy(PATTERN,pattern);
-    pds_string_clean_beginning(PATTERN,' ');
-    pds_string_clean_ending(PATTERN,' ');
+    pds_string_multi_clean_beginning(PATTERN,"\t ");
+    pds_string_multi_clean_ending (PATTERN,"\t ");
 
     N=strlen(PATTERN);
     
 
-    fd=fopen(pathname,"r");
+    fd=fopen(filepath,"r");
     if(fd==NULL)
     {
-        fprintf(stderr,"ERROR opening the file:%s\n",pathname);
+        fprintf(stderr,"ERROR opening the file:%s\n",filepath);
         return NULL;
     }
 
@@ -1011,7 +1047,7 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
         if(LINE!=NULL)
         {
 
-            pds_string_clean_beginning (LINE,' ');
+            pds_string_multi_clean_beginning (LINE,"\t ");
 
             Nl=strlen(LINE);
             if(Nl>=N)
@@ -1035,12 +1071,32 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
 
     if(DATA==NULL)
     {
-        DATA=(char*)calloc(1,sizeof(char));
+        if(default_value!=NULL)
+        {
+            DATA=(char*)calloc(strlen(default_value)+1,sizeof(char));
+            if(DATA!=NULL)
+            strcpy(DATA,default_value);
+        }
     }
+    else
+    {
+        if(reject!=NULL)
+        pds_string_multi_clean_beginning (DATA,reject);
+        pds_string_multi_clean_ending (DATA,"\t ");
 
-    pds_string_clean_beginning (DATA,' ');
-    pds_string_clean_ending (DATA,'\n');
-    pds_string_clean_ending (DATA,' ');
+        if(strlen(DATA)==0)
+        {
+            free(DATA);DATA=NULL;
+
+            if(default_value!=NULL)
+            {
+                DATA=(char*)calloc(strlen(default_value)+1,sizeof(char));
+                if(DATA!=NULL)
+                strcpy(DATA,default_value);
+            }
+        }
+
+    }
 
     fclose(fd);
     free(LINE);
@@ -1049,26 +1105,72 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
     return DATA;
 }
 
-/** \fn int pds_get_filedata_int(const char *pathname,const char* pattern)
+
+/** \fn int pds_get_filedata_int(const char *filepath,const char* pattern, const char* reject,int default_value)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el valor int despues de el primer patrón pattern encontrado.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  el valor entero despues del primer patrón pattern encontrado.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
- *  \return Retorna el valor en int con el dato encontrado.
- *  En caso de error es retornado zero.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer el valor 1000 usaremos:
+ * \code{.c}
+ * DATA=pds_get_filedata_int("mydata.ini","MY_FIRST_DATA","= ",-1);
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna default_value.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna default_value.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia o en caso de algun error.
+ *  \return Retorna el dato encontrado, o default_value si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-int pds_get_filedata_int(const char *pathname,const char* pattern)
+int pds_get_filedata_int(const char *filepath,const char* pattern, const char* reject,int default_value)
 {
     char *str=NULL;
     int d;
+    char *buffer=NULL;
 
-    str=pds_get_filedata_string(pathname,pattern);
-    if(str==NULL)    return 0;
+    if(filepath==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_int): First parameter equal to NULL. Returning 0.\n");
+        return default_value;
+    }
+    if(pattern ==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_int): Second parameter equal to NULL. Returning 0.\n");
+        return default_value;
+    }
+    
+    buffer=pds_itoa(default_value,10);
+    if(buffer==NULL)    
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_int): Memory alloc problem. Returning 0.\n");
+        return default_value;
+    }
 
+    str=pds_get_filedata_string(filepath,pattern,reject,buffer);
+    free(buffer);
+
+    if(str==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_int): Searching unsuccessful. Returning 0.\n");
+        return default_value;
+    }
+    
     d=atoi(str);
 
     free(str);
@@ -1076,44 +1178,109 @@ int pds_get_filedata_int(const char *pathname,const char* pattern)
     return d;
 }
 
-/** \fn int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+/** \fn int pds_get_filedata_strcmp(const char *filepath,const char* pattern,const char* reject,const char* dat)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  TRUE si el valor despues de el primer patrón pattern encontrado es dat.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  PDS_OK si el valor despues de el primer patrón pattern encontrado es dat.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
- *  \param[in] dat Dato a comparar.
- *  \return Retorna TRUE si el valor dat es encontrado despues del primer 
- *  patrón pattern. En caso de error es retornado FALSE.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para comparar el valor TRUE usaremos:
+ * \code{.c}
+ * d=pds_get_filedata_strcmp("mydata.ini","MY_THIRD_DATA","= ",TRUE);
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna PDS_WRONG.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna PDS_WRONG.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  \param[in] dat Es dato a comparar. Si dat==NULL se retornará PDS_WRONG.
+ *  no es encontrado, o si el valor encontrado es una cadena vacia o en caso de algun error.
+ *  \return Retorna PDS_OK si el valor dat es encontrado despues del primer 
+ *  patrón pattern. En caso de error es retornado PDS_WRONG.
  *  \ingroup PdsFilesFuncGroup
  */
-int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+int pds_get_filedata_strcmp(const char *filepath,const char* pattern,const char* reject,const char* dat)
 {
     char *str=NULL;
     int d;
 
-    str=pds_get_filedata_string(pathname,pattern);
-    if(str==NULL)    return 0;
 
-    if(strcmp(dat,str)==0)  d=TRUE;
-    else                    d=FALSE;
+    if(filepath==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_strcmp): First parameter equal to NULL. Returning PDS_WRONG.\n");
+        return PDS_WRONG;
+    }
+    if(pattern ==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_strcmp): Second parameter equal to NULL. Returning PDS_WRONG.\n");
+        return PDS_WRONG;
+    }
+    if(dat     ==NULL)
+    {
+        fprintf(stdout,"WARNING(pds_get_filedata_strcmp): Fourth parameter equal to NULL. Returning PDS_WRONG.\n");
+        return PDS_WRONG;
+    }
+
+    str=pds_get_filedata_string(filepath,pattern,reject,"");
+    if(str==NULL)
+    {
+        //fprintf(stdout,"WARNING(pds_get_filedata_int): Searching unsuccessful. Returning PDS_WRONG.\n");
+        return PDS_WRONG;
+    }
+
+    if(strcmp(dat,str)==0)  d=PDS_OK;
+    else                    d=PDS_WRONG;
 
     free(str);
 
     return d;
 }
 
-/** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
+/** \fn PdsCellString *pds_get_filedata_cell_string(const char *filepath,const char* pattern,const char *reject,const char *default_value, const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado, pero estos datos son
  *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer llos datos "dat1, dat2  , dat3" usaremos:
+ * \code{.c}
+ * Cell=pds_get_filedata_cell_string("mydata.ini","MY_FOURTH_DATA","= ","valor por defecto",";,");
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna NULL.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna NULL.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  Si la variable default_value es usada entonces reject no es aplicado sobre el dato retornado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia.
+ *  Si default_value==NULL y no es encontrado ningun dato o este esta vacio entonces
+ *  NULL es retornando.
  *  \param[in] separator Separador de texto. Si separator es igual a NULL o vacia la 
  *  función retorna la cadena sem dividir.
  *  \return Retorna una nueva estructurs PdsCellString con los datos encontrado.
@@ -1121,16 +1288,18 @@ int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char*
  *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
+PdsCellString *pds_get_filedata_cell_string(const char *filepath,const char* pattern,
+                                            const char *reject,const char *default_value, 
+                                            const char *separator)
 {
     char *DATA=NULL;
     PdsCellString *CELL=NULL;
     int i;
     
-    if(pathname==NULL)  return NULL;
+    if(filepath==NULL)  return NULL;
     if(pattern==NULL)   return NULL;
 
-    DATA=pds_get_filedata_string(pathname,pattern);
+    DATA=pds_get_filedata_string(filepath,pattern,reject,default_value);
     if(DATA==NULL)  return  NULL;
 
     if(separator!=NULL) CELL=pds_strsep_cell_string (DATA,separator);
@@ -1138,8 +1307,8 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
 
     for(i=0;i<CELL->Ncell;i++)
     {
-        pds_string_clean_beginning(CELL->data[i],' ');
-        pds_string_clean_ending(CELL->data[i],' ');
+        pds_string_multi_clean_beginning(CELL->data[i],"\t ");
+        pds_string_multi_clean_ending(CELL->data[i],"\t ");
     }
 
     free(DATA);
@@ -1147,10 +1316,10 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
 }
 
 /** \fn int pds_is_file(const char *path)
- *  \brief TRUE si es un fichero (simbólico o real) o FALSE si no.
+ *  \brief PDS_OK si es un fichero (simbólico o real) o PDS_WRONG si no.
  *
  *  \param[in] path Dirección de fichero a testar.
- *  \return Retorna TRUE is es un fichero o FALSE si no.
+ *  \return Retorna PDS_OK is es un fichero o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_is_file(const char *path)
@@ -1158,18 +1327,18 @@ int pds_is_file(const char *path)
     struct stat stat_result;
     stat(path, &stat_result);
 
-    if( access( path, F_OK ) == -1 ) return FALSE;
+    if( access( path, F_OK ) == -1 ) return PDS_WRONG;
 
-    if(S_ISREG(stat_result.st_mode)==0) return FALSE;
-    else                                return TRUE;
+    if(S_ISREG(stat_result.st_mode)==0) return PDS_WRONG;
+    else                                return PDS_OK;
 }
 
 
 /** \fn int pds_is_dir(const char *path)
- *  \brief TRUE is es un directorio (simbólico o real) o FALSE si no.
+ *  \brief PDS_OK is es un directorio (simbólico o real) o PDS_WRONG si no.
  *
  *  \param[in] path Dirección de directorio a testar.
- *  \return Retorna TRUE is es un directorio o FALSE si no.
+ *  \return Retorna PDS_OK is es un directorio o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_is_dir(const char *path)
@@ -1177,10 +1346,10 @@ int pds_is_dir(const char *path)
     struct stat stat_result;
     stat(path, &stat_result);
 
-    if( access( path, F_OK ) == -1 ) return FALSE;
+    if( access( path, F_OK ) == -1 ) return PDS_WRONG;
 
-    if(S_ISDIR(stat_result.st_mode))    return TRUE;
-    else                                return FALSE;
+    if(S_ISDIR(stat_result.st_mode))    return PDS_OK;
+    else                                return PDS_WRONG;
 }
 
 
@@ -1233,7 +1402,7 @@ long pds_get_number_of_chars(const char *path)
     if(fd==NULL)    return -1;
 
     count=0;
-    while(c=fgetc(fd)) 
+    while((c=fgetc(fd))) 
     {
         if(c == EOF) break;
         count++;
@@ -1244,42 +1413,42 @@ long pds_get_number_of_chars(const char *path)
 }
 
 /** \fn int pds_exist_file(const char *path)
- *  \brief Retorna TRUE si path es un fichero real o simbólico (no un directorio) 
+ *  \brief Retorna PDS_OK si path es un fichero real o simbólico (no un directorio) 
  *  y es accesible.
  *
  *  \param[in] path Dirección de fichero a testar.
- *  \return Retorna TRUE si el archivo existe o FALSE si no.
+ *  \return Retorna PDS_OK si el archivo existe o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_exist_file(const char *path)
 {
     if(pds_archive_is_accessible(path))
     {
-        if(pds_is_file(path))   return TRUE;
-        else                    return FALSE;
+        if(pds_is_file(path))   return PDS_OK;
+        else                    return PDS_WRONG;
     }
-    else    return FALSE;
+    else    return PDS_WRONG;
     
 }
 
 
 /** \fn int pds_archive_is_accessible(const char *path)
- *  \brief Retorna TRUE si el archivo simbólico o real (Directorio o fichero) 
+ *  \brief Retorna PDS_OK si el archivo simbólico o real (Directorio o fichero) 
  *  es accesible.
  *
  *  \param[in] path Dirección de archivo a testar.
- *  \return Retorna TRUE si el archivo existe o FALSE si no.
+ *  \return Retorna PDS_OK si el archivo existe o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_archive_is_accessible(const char *path)
 {
     if( access( path, F_OK ) != -1 ) 
     {
-        return TRUE;
+        return PDS_OK;
     } 
     else
     {
-        return FALSE;
+        return PDS_WRONG;
     }
 }
 
@@ -1296,7 +1465,7 @@ int pds_archive_is_accessible(const char *path)
  *  \param[in] filename_in Archivo de entrada donde se realizará la búsqueda.
  *  \param[in] pat Patron a buscar.
  *  \param[in] rep Patron a de remplazo.
- *  \return Retorna TRUE si todo fue bien o FALSE si no.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_file_pattern_replacement(const char *filename_out,const char *filename_in,const char *pat,const char *rep)
@@ -1305,20 +1474,20 @@ int pds_file_pattern_replacement(const char *filename_out,const char *filename_i
     char *str_out=NULL;
     FILE *fd=NULL;
 
-    if(filename_out==NULL)   return FALSE;
-    if(filename_in==NULL)    return FALSE;
-    if(pat==NULL)           return FALSE;
-    if(rep==NULL)           return FALSE;
+    if(filename_out==NULL)   return PDS_WRONG;
+    if(filename_in==NULL)    return PDS_WRONG;
+    if(pat==NULL)           return PDS_WRONG;
+    if(rep==NULL)           return PDS_WRONG;
 
 
     str_in=pds_string_new_from_file(filename_in);
-    if(str_in==NULL)    return FALSE;
+    if(str_in==NULL)    return PDS_WRONG;
 
-    str_out=pds_string_new_with_replacement(str_in,pat,rep);
+    str_out=pds_string_pattern_replacement(str_in,pat,rep);
     if(str_out==NULL)
     {
         free(str_in);
-        return FALSE;
+        return PDS_WRONG;
     }
 
     fd=fopen(filename_out,"w");
@@ -1326,7 +1495,7 @@ int pds_file_pattern_replacement(const char *filename_out,const char *filename_i
     {
         free(str_in);
         free(str_out);
-        return FALSE;
+        return PDS_WRONG;
     }
     fprintf(fd,"%s",str_out);
     fclose(fd);
@@ -1334,7 +1503,7 @@ int pds_file_pattern_replacement(const char *filename_out,const char *filename_i
     free(str_in);
     free(str_out);
 
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -1362,7 +1531,9 @@ replace=func(content);
 \endcode
  *  este será remplazado por el contenido de la cadena replace, luego la cadena 
  *  replace será liberada internamente con free(replace).
- *  \return Retorna TRUE si todo fue bien o FALSE si no.
+ *  Si la funcion func retorna NULL, la escritura en filename_out es detenida y
+ *  se retorna PDS_WRONG.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_file_content_replacement(   const char *filename_out,const char *filename_in,
@@ -1377,27 +1548,25 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
     char *rep=NULL;
     char *str_ptr=NULL;
     char *str_last=NULL;
-    long N,Nopen,Nclose,Ncontent,i,n;
+    long Nclose,Ncontent,i,n;
 
-    if(filename_out==NULL)   return FALSE;
-    if(filename_in==NULL)    return FALSE;
-    if(pat_open==NULL)       return FALSE;
-    if(pat_close==NULL)      return FALSE;
-    if((*func)==NULL)        return FALSE;
+    if(filename_out==NULL)   return PDS_WRONG;
+    if(filename_in==NULL)    return PDS_WRONG;
+    if(pat_open==NULL)       return PDS_WRONG;
+    if(pat_close==NULL)      return PDS_WRONG;
+    if((*func)==NULL)        return PDS_WRONG;
 
     str_in= pds_string_new_from_file(filename_in);
-    if(str_in==NULL)    return FALSE;
+    if(str_in==NULL)    return PDS_WRONG;
 
     str_ptr=str_in;
-    N=strlen(str_in);
-    Nopen=strlen(pat_open);
     Nclose=strlen(pat_close);
 
     fd=fopen(filename_out,"w");
     if(fd==NULL)
     {
         free(str_in);
-        return FALSE;
+        return PDS_WRONG;
     }
 
 
@@ -1405,7 +1574,7 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
     {
         str_last=str_ptr;
 
-        content=pds_string_new_rawdata_after_match(str_ptr,pat_open,pat_close,&str_ptr);
+        content=pds_string_get_match_rawdata(str_ptr,pat_open,pat_close,&str_ptr);
         
         if(content!=NULL)
         {
@@ -1414,6 +1583,13 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
             for(i=0;i<n;i++)    fputc(str_last[i],fd);
 
             rep=(*func)(content);
+            if(rep==NULL)
+            {
+                free(str_in);
+                free(content);
+                fclose(fd);
+                return PDS_WRONG;
+            }
 
             fputs(rep,fd);
             fputs(pat_close,fd);
@@ -1423,6 +1599,7 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
         }
         else
         {
+            
             fputs(str_last,fd);
             break;
         }
@@ -1430,7 +1607,7 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
     }
     fclose(fd); 
   
-    return TRUE;
+    return PDS_OK;
 }
 
 
