@@ -22,77 +22,233 @@
 
 #include <stdarg.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 #include <pds/pdsstring.h>
 #include <pds/pdscstring.h>
 #include <pds/pdsfilesfunc.h>
 
+/** \fn int isintnumber(const char *str)
+ *  \brief Esta función verifica si la cadena contiene un número entero. La función
+ *  solo desconsidera espacios en blanco iniciales y finales
+ *  \param[in] str Cadena a anlizar.
+ *  \return Retorna PDS_OK si es un numero y PDS_WRONG quando no lo es o str==NULL
+ *  o str es una cadena vacia o hubo un error de allocacion de memoria.
+ *  \ingroup PdsStringGroup
+ */
+int isintnumber(const char *str)
+{ 
+    int N;
+    int i;
+    char *dump=NULL;
+
+    if(str==NULL)   return PDS_WRONG;
+
+    N=strlen(str);
+    if(N==0)        return PDS_WRONG;
+
+    dump=(char *)calloc(N+1,sizeof(char));
+    if(dump==NULL)  return  PDS_WRONG;
+    
+    strcpy(dump,str);
+    pds_string_clean_beginning(dump,' ');
+    pds_string_clean_ending(dump,' ');
+
+    N=strlen(dump);
+    for(i=0;i<N;i++)
+    {
+        if(i==0)
+        {
+            if((isdigit(dump[i])!=0)||(dump[i]=='+')||(dump[i]=='-'))
+            {
+                i=i;
+            }
+            else
+            {
+                free(dump);
+                return PDS_WRONG;
+            } 
+            
+        }
+        else
+        {
+            if(isdigit(dump[i])==0)
+            {
+                free(dump);
+                return PDS_WRONG;
+            }
+        }
+    }
+
+    return PDS_OK;
+}
+ 
+
+/** \fn char *pds_itoa(int num,int base)
+ *  \brief Esta función es similar a la función itoa() pero retorna una nueva
+ *  cadena de texto con el número num en la base base.
+ *  \param[in] num Número a escribir.
+ *  \param[in] base Base del número a escribir.
+ *  \return Retorna una nueva cadena con el numero num en la base base..
+ *  Retorna NULL si hubo problemas de reserva de memoria o base <=0 .
+ *  \ingroup PdsStringGroup
+ */
+char *pds_itoa(int num,int base)
+{   
+    char *buffer=NULL;
+    int N,tmp,i;
+    int signo=0;
+
+    if(base<=0) return NULL;
+
+    if(num<0)
+    {
+        signo=1;
+        num=-num;
+    }
+
+    if(signo==1)    N=0;
+    else            N=1;
+
+    tmp=num;
+    do{
+        tmp=(tmp/base);
+        N++;
+    }while (tmp>0);
+
+    buffer=(char*)calloc(N+1,sizeof(char));
+    if(buffer!=NULL)
+    {        
+        i=0;
+        do{
+            tmp=num%base;
+            num=num/base;
+            buffer[N-1-i]=tmp;
+            i++;
+        }while(num>0);
+
+        if(signo==1) buffer[0]='-';
+    }
+    return buffer;
+}
+
+/** \fn char *pds_toupper(const char *str)
+ *  \brief Esta función es similar a la función toupper() pero transforma una  
+ *  cadena de texto (y no un caracter) a letras mayúsculas.
+ *  \param[in] str Cadena a convetir en mayúsculas.
+ *  \return Retorna una nueva cadena con el resultado de convertir en mayúsculas.
+ *  Retorna NULL si str es NULL o si hubo problemas de reserva de memoria.
+ *  \ingroup PdsStringGroup
+ */
+char *pds_toupper(const char *str)
+{
+    char *dat=NULL;
+    int i;
+    
+    if(str==NULL)   return  NULL;
+    
+    int N=strlen(str);
+    dat=(char *)calloc(N+1,sizeof(char));
+    if(dat==NULL)   return  NULL;
+
+    for(i=0;i<N;i++) dat[i]=toupper(str[i]);
+    
+    return dat;
+}
+
+/** \fn int pds_inupper(char *str)
+ *  \brief Esta función  modifica una cadena de texto a letras mayúsculas.
+ *  \param[in] str Cadena a convetir en mayúsculas.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si str es NULL.
+ *  \ingroup PdsStringGroup
+ */
+int pds_inupper(char *str)
+{
+    int i;
+    
+    if(str==NULL)   return  PDS_WRONG;
+    
+    int N=strlen(str);
+
+    for(i=0;i<N;i++) str[i]=toupper(str[i]);
+    
+    return PDS_OK;
+}
+
+/** \fn char *pds_tolower(const char *str)
+ *  \brief Esta función es similar a la función tolower() pero transforma una  
+ *  cadena de texto (y no un caracter) a letras minúsculas.
+ *  \param[in] str Cadena a convetir en minúsculas.
+ *  \return Retorna una nueva cadena con el resultado de convertir en minúsculas.
+ *  Retorna NULL si str es NULL o si hubo problemas de reserva de memoria.
+ *  \ingroup PdsStringGroup
+ */
+char *pds_tolower(const char *str)
+{
+    char *dat=NULL;
+    int i;
+    
+    if(str==NULL)   return  NULL;
+    
+    int N=strlen(str);
+    dat=(char *)calloc(N+1,sizeof(char));
+    if(dat==NULL)   return  NULL;
+
+    for(i=0;i<N;i++) dat[i]=tolower(str[i]);
+    
+    return dat;
+}
+
+
+/** \fn int pds_inlower(char *str)
+ *  \brief Esta función  modifica una cadena de texto a letras minúsculas.
+ *  \param[in] str Cadena a convetir en minúsculas.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si str es NULL.
+ *  \ingroup PdsStringGroup
+ */
+int pds_inlower(char *str)
+{
+    int i;
+    
+    if(str==NULL)   return  PDS_WRONG;
+    
+    int N=strlen(str);
+
+    for(i=0;i<N;i++) str[i]=tolower(str[i]);
+    
+    return PDS_OK;
+}    
+
 /** \fn char* pds_sprintf(const char *format, ...)
  *  \brief Similar a sprintf pero esta retorna un puntero a una nueva cadena con 
  *  el texto.
  *
  *  \param[in] format Formato de texto de salida.
  *  \param[in] ... Otros argumentos.
- *  \return Retorna un puntero a una nueva cadena con el texto.
+ *  \return Retorna un puntero a una nueva cadena con el texto. O NULL en caso de error.
  *  \ingroup PdsStringGroup
  */
 char* pds_sprintf(const char *format, ...)
 {
     char *char_string=NULL;
-    char *p=NULL;
-    int N=-1,n;
-    int len,i;
-    char buffer[32];
-    int val;
     va_list args;               /* points to each unnamed arg in turn */
+    int N;
 
     va_start( args, format );   /* make args point to 1st unnamed arg */
-    N=strlen(format);
-    for (p = (char*)format; *p; p++) 
-    {
-        if (*p == '%') 
-        {
-            p++;
-
-            i=0;
-            while(isalpha((int)(*p))==0)
-            {
-                buffer[i]=(char)(*p); 
-                i++;
-                p++;
-            }
-            buffer[i]=0;
-            len=atoi(buffer);
-
-            if(*p=='s')         {n=strlen(va_arg(args, char *));}
-            else if(*p=='c')    {val = va_arg(args, int); n=1;}
-            else                {val = va_arg(args, int); n=64;}//<----Problemas aqui si es entregado %64s
-            if(len>n)   N=N+len;
-            else        N=N+n;
-        }
-    }
+    N=vsnprintf(NULL,0,format, args);
     va_end( args );             /* clean up when done */
 
-    if(N==-1)
-    {
-        return NULL;
-    }
-
     char_string=(char*)calloc(N+1,sizeof(char));
     if(char_string==NULL)
     {
         return NULL;
     }
 
-
     va_start( args, format );   /* make args point to 1st unnamed arg */
     vsprintf( char_string, format, args );
     va_end( args );             /* clean up when done */
 
-
-    char_string=(char*)realloc(char_string,strlen(char_string)+1);
-
     return char_string;
 }
 
@@ -183,6 +339,7 @@ PdsCellString *pds_strsep_cell_string(const char *str, const char *delim)
             //if(strlen(token)>0) 
             {
                 dat=pds_cell_string_add(Tok,token);
+                if(dat==PDS_WRONG)   fprintf(stderr,"ERROR: Adding values to the PdsCellString\n");
             }
             
         }
@@ -201,6 +358,8 @@ PdsCellString *pds_strsep_cell_string(const char *str, const char *delim)
  *  \param[in] str0 Primera cadena a comparar.
  *  \param[in] str1 Segunda cadena a comparar.
  *  \return Retorna 0 si las cadenas son iguales (Case Insensitive).
+ *  Retorna < 0 si str0 is less than str1.
+ *  Retorna > 0 si str1 is less than str0.
  *  \ingroup PdsStringGroup
  */
 int pds_strcicmp(const char *str0,const char *str1)
@@ -215,6 +374,45 @@ int pds_strcicmp(const char *str0,const char *str1)
     }
 }
 
+/** \fn int pds_strlexcmp(const char *str0,const char *str1)
+ *  \brief Esta función es similar a la función strcmp pero compara lexicograficamente
+ *  las cadenas, donde si las cadenas son iguales
+ *  la funcion retorna 0.
+ *  \param[in] str0 Primera cadena a comparar.
+ *  \param[in] str1 Segunda cadena a comparar.
+ *  \return Retorna 0 si las cadenas son iguales (Case Insensitive).
+ *  Retorna < 0 si str0 is less than str1.
+ *  Retorna > 0 si str1 is less than str0.
+ *  \ingroup PdsStringGroup
+ */
+int pds_strlexcmp(const char *str0,const char *str1)
+{
+    int d;
+    int a0,a1;
+
+
+    for (;; str0++, str1++) 
+    {
+        if( isdigit(*str0) && isdigit(*str1) )
+        {
+            a0=atoi(str0);
+            a1=atoi(str1);
+            //printf("[%d %d]\n",a0,a1);
+            if(a0<a1)   return -1;
+            if(a1<a0)   return +1;
+
+        }
+        else
+        {
+            //printf("<%c %c>\n",*str0,*str1);
+            d = tolower(*str0) - tolower(*str1);
+            if( (d != 0) || (*str0==0) )
+                return d;
+        }
+    }
+
+}
+
 
 
 /** \fn int pds_string_multi_clean_beginning(char *str,const char *pat)
@@ -223,7 +421,7 @@ int pds_strcicmp(const char *str0,const char *str1)
  *  movidos de lugar.
  *  \param[in] str Cadena a limpiar.
  *  \param[in] pat Caracteres a limpiar.
- *  \return Retorna TRUE si las cadena fue limpiada correctamente o retorna FALSE si
+ *  \return Retorna PDS_OK si las cadena fue limpiada correctamente o retorna PDS_WRONG si
  *  str o pat es igual a NULL;
  *  \ingroup PdsStringGroup
  */
@@ -233,8 +431,8 @@ int pds_string_multi_clean_beginning(char *str,const char *pat)
     int ntrash;
     int found;
 
-    if(str==NULL)   return FALSE;
-    if(pat==NULL)   return FALSE;
+    if(str==NULL)   return PDS_WRONG;
+    if(pat==NULL)   return PDS_WRONG;
 
     ntrash=0;
     len=strlen(str);
@@ -242,13 +440,13 @@ int pds_string_multi_clean_beginning(char *str,const char *pat)
 
     for(i=0;i<len;i++)
     {
-        found=FALSE;
+        found=PDS_WRONG;
         for(j=0;j<n;j++)
         {
-            if(str[i]==pat[j])   found=TRUE;
+            if(str[i]==pat[j])   found=PDS_OK;
         }
         
-        if(found==TRUE) ntrash++;
+        if(found==PDS_OK) ntrash++;
         else            break;
     }
     
@@ -261,7 +459,7 @@ int pds_string_multi_clean_beginning(char *str,const char *pat)
         for(i=len-ntrash;i<len;i++) str[i]=0;
     }
     
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -271,7 +469,7 @@ int pds_string_multi_clean_beginning(char *str,const char *pat)
  *  cerados.
  *  \param[in] str Cadena a limpiar.
  *  \param[in] pat Caracteres a limpiar.
- *  \return Retorna TRUE si las cadena fue limpiada correctamente o retorna FALSE si
+ *  \return Retorna PDS_OK si las cadena fue limpiada correctamente o retorna PDS_WRONG si
  *  str o pat es igual a NULL;
  *  \ingroup PdsStringGroup
  */
@@ -280,25 +478,25 @@ int pds_string_multi_clean_ending(char *str,const char *pat)
     int len,i,n,j;
     int found;
 
-    if(str==NULL)   return FALSE;
-    if(pat==NULL)   return FALSE;
+    if(str==NULL)   return PDS_WRONG;
+    if(pat==NULL)   return PDS_WRONG;
 
     len=strlen(str);
     n=strlen(pat);
 
     for(i=len-1;i>=0;i--)
     {
-        found=FALSE;
+        found=PDS_WRONG;
         for(j=0;j<n;j++)
         {
-            if(str[i]==pat[j])   found=TRUE;
+            if(str[i]==pat[j])   found=PDS_OK;
         }
 
-        if(found==TRUE)   str[i]=0;
+        if(found==PDS_OK)   str[i]=0;
         else break;
     }
     
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -308,7 +506,7 @@ int pds_string_multi_clean_ending(char *str,const char *pat)
  *  movidos de lugar.
  *  \param[in] str Cadena a limpiar.
  *  \param[in] c Caracter a limpiar.
- *  \return Retorna TRUE si las cadena fue limpiada correctamente o retorna FALSE si
+ *  \return Retorna PDS_OK si las cadena fue limpiada correctamente o retorna PDS_WRONG si
  *  str es igual a NULL;
  *  \ingroup PdsStringGroup
  */
@@ -317,7 +515,7 @@ int pds_string_clean_beginning(char *str,char c)
     int len,i;
     int ntrash;
 
-    if(str==NULL)   return FALSE;
+    if(str==NULL)   return PDS_WRONG;
 
     ntrash=0;
     len=strlen(str);
@@ -337,7 +535,7 @@ int pds_string_clean_beginning(char *str,char c)
         for(i=len-ntrash;i<len;i++) str[i]=0;
     }
     
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -348,7 +546,7 @@ int pds_string_clean_beginning(char *str,char c)
  *  cerados.
  *  \param[in] str Cadena a limpiar.
  *  \param[in] c Caracter a limpiar.
- *  \return Retorna TRUE si las cadena fue limpiada correctamente o retorna FALSE si
+ *  \return Retorna PDS_OK si las cadena fue limpiada correctamente o retorna PDS_WRONG si
  *  str es igual a NULL;
  *  \ingroup PdsStringGroup
  */
@@ -356,7 +554,7 @@ int pds_string_clean_ending(char *str,char c)
 {
     int len,i;
 
-    if(str==NULL)   return FALSE;
+    if(str==NULL)   return PDS_WRONG;
 
     len=strlen(str);
 
@@ -366,7 +564,7 @@ int pds_string_clean_ending(char *str,char c)
         else break;
     }
     
-    return TRUE;
+    return PDS_OK;
 }
 
 
@@ -385,7 +583,7 @@ char * pds_string_new_from_file(const char *path)
     long i;
     int c;
 
-    if(pds_exist_file(path)==FALSE) return NULL;
+    if(pds_exist_file(path)==PDS_WRONG) return NULL;
 
     N=pds_get_number_of_chars(path);
 
@@ -477,7 +675,7 @@ char *pds_strcat_cell_string(const PdsCellString *celldata,const char *separator
 
 }
 
-/** \fn int pds_string_how_many_times(const char *str,const char *pat)
+/** \fn int pds_string_get_number_of_patterns(const char *str,const char *pat)
  *  \brief Esta función cuenta la cantidad de coincidencias de la cadena pat
  *  en la cadena str.
  *
@@ -488,7 +686,7 @@ char *pds_strcat_cell_string(const PdsCellString *celldata,const char *separator
  *  \return Retorna el número de coincidencias o -1 en caso de error.
  *  \ingroup PdsStringGroup
  */
-int pds_string_how_many_times(const char *str,const char *pat)
+int pds_string_get_number_of_patterns(const char *str,const char *pat)
 {
     long N;
     long L;
@@ -517,7 +715,7 @@ int pds_string_how_many_times(const char *str,const char *pat)
 }
 
 
-/** \fn char *pds_string_new_with_replacement(const char *str,const char *pat,const char *rep)
+/** \fn char *pds_string_pattern_replacement(const char *str,const char *pat,const char *rep)
  *  \brief Esta función busca en una cadena str un patrón pat y los remplaza con 
  *  el contenido de la cadena rep, el resultado es retornado en una nueva cadena;
  *
@@ -529,7 +727,7 @@ int pds_string_how_many_times(const char *str,const char *pat)
  *  \return Retorna una nueva cadena con el resultado de remplazar pat por rep en str.
  *  \ingroup PdsStringGroup
  */
-char *pds_string_new_with_replacement(const char *str,const char *pat,const char *rep)
+char *pds_string_pattern_replacement(const char *str,const char *pat,const char *rep)
 {
     int n,Nstr,Npat,Nrep;
     int is,jn;
@@ -539,7 +737,7 @@ char *pds_string_new_with_replacement(const char *str,const char *pat,const char
     if(pat==NULL)   return NULL;
     if(rep==NULL)   return NULL;
 
-    n=pds_string_how_many_times(str,pat);
+    n=pds_string_get_number_of_patterns(str,pat);
     Nstr=strlen(str);
     Npat=strlen(pat);
     Nrep=strlen(rep);
@@ -572,7 +770,7 @@ char *pds_string_new_with_replacement(const char *str,const char *pat,const char
 }
 
 
-/** \fn char *pds_string_new_rawdata_after_match(const char *str,const char *pat_open,const char *pat_close,char **str_ptr)
+/** \fn char *pds_string_get_match_rawdata(const char *str,const char *pat_open,const char *pat_close,char **str_ptr)
  *  \brief Esta función busca en una cadena str, los datos entre un patrón 
  *  pat_open y uno pat_close. Retorna los datos en una nueva cadena de texto.
  *
@@ -584,12 +782,12 @@ char *pds_string_new_with_replacement(const char *str,const char *pat,const char
 \code{.c}
 char str[]="hola <b> Fernando\n</b> como estas";
 char *str_ptr=NULL;
-char *rawdata=pds_string_new_rawdata_after_match(str,"<b>","</b>",&str_ptr);
+char *rawdata=pds_string_get_match_rawdata(str,"<b>","</b>",&str_ptr);
 \endcode
  *  Ejemplos : Busca la coincidencia en str.
 \code{.c}
 char str[]="hola <b> Fernando\n</b> como estas";
-char *rawdata=pds_string_new_rawdata_after_match(str,"<b>","</b>",NULL);
+char *rawdata=pds_string_get_match_rawdata(str,"<b>","</b>",NULL);
 \endcode
  *  \param[in] str Cadena donde se realizará la búsqueda.
  *  \param[in] pat_open Patrón de apertura.
@@ -601,11 +799,11 @@ char *rawdata=pds_string_new_rawdata_after_match(str,"<b>","</b>",NULL);
  *  \return Retorna una nueva cadena con el contenido entre pat_open y pat_close.
  *  \ingroup PdsStringGroup
  */
-char *pds_string_new_rawdata_after_match(const char *str,const char *pat_open,const char *pat_close,char **str_ptr)
+char *pds_string_get_match_rawdata(const char *str,const char *pat_open,const char *pat_close,char **str_ptr)
 {
     long i;
-    long offset_open;
-    long offset_close;
+    long offset_open;//inicio del patron open
+    long offset_close;//inicio del patron close
     long N,Nopen,Nclose;
 
     char *str0=NULL;
@@ -689,7 +887,7 @@ char *pds_string_new_rawdata_after_match(const char *str,const char *pat_open,co
     for(i=0;i<data_length;i++)
     data[i]=str[offset_open+Nopen+i];
 
-    if( (offset_close+Nclose)<N)
+    if( (offset_close+Nclose)<=N)
         *str_ptr=str0+(offset_close+Nclose);
     else
         *str_ptr=NULL;
@@ -698,3 +896,122 @@ char *pds_string_new_rawdata_after_match(const char *str,const char *pat_open,co
     return data;
 }
 
+
+/** \fn char *pds_string_content_replacement( const char *str_in, const char *pat_open,const char *pat_close, char *(*func)(const char *))
+ *  \brief Esta función busca en una cadena de texto str_in, el contenido
+ *  entre un patrón pat_open y pat_close y lo remplaza  por el valor devuelto de 
+ *  la función func, el resultado de todo esto es retornado en una nueva cadena 
+ *  de texto.
+ *
+ *  La función func debe ser de la forma :
+\code{.c}
+char *func(const char* content);
+\endcode
+ *
+\code{.c}
+str_out=pds_string_content_replacement(str_in,"<b>","</b>",func);
+\endcode
+ *  \param[in] str_in Cadena de entrada donde se realizará la búsqueda.
+ *  \param[in] pat_open Patrón inicial a buscar.
+ *  \param[in] pat_close Patrón final a buscar.
+ *  \param[in] func Es una función que se usará para remplazar el contenido 
+ *  encontrado. Por ejemplo si entre pat_open y pat_close es encontrado content
+\code{.c}
+replace=func(content);
+\endcode
+ *  este será remplazado por el contenido de la cadena replace, luego la cadena 
+ *  replace será liberada internamente con free(replace).
+ *  Si la funcion func retorna NULL, la busqueda en str_in es detenida y
+ *  se retorna NULL.
+ *  \return Retorna una nueva cadena de texto si todo fue bien o NULL si no.
+ *  \ingroup PdsStringGroup
+ */
+char *pds_string_content_replacement( const char *str_in,
+                                     const char *pat_open,const char *pat_close,
+                                     char *(*func)(const char *))
+{
+    char *content=NULL;
+    char *rep=NULL;
+    char *str_ptr=NULL;
+    char *str_last=NULL;
+    long Nclose,Ncontent,i,n;
+
+    PdsCellString *Cout=NULL;
+    char *str_out=NULL;
+
+    if(str_in==NULL)    return NULL;
+    if(pat_open==NULL)  return NULL;
+    if(pat_close==NULL) return NULL;
+    if((*func)==NULL)   return NULL;
+
+
+    str_ptr=(char *)str_in;
+    Nclose=strlen(pat_close);
+
+
+    Cout=pds_cell_string_new(0);
+    if(Cout==NULL)      return NULL;
+
+
+    while(1)
+    {
+        str_last=str_ptr;
+
+        content=pds_string_get_match_rawdata(str_ptr,pat_open,pat_close,&str_ptr);
+        
+        if(content!=NULL)
+        {
+            Ncontent=strlen(content);
+            n=( (long)(str_ptr-str_last) )-Ncontent-Nclose;
+
+            rep=calloc(n+1,sizeof(char));
+            if(rep==NULL)
+            {
+                free(content);
+                pds_cell_string_free(Cout);
+                return NULL;
+            }
+            
+            for(i=0;i<n;i++)    rep[i]=str_last[i];
+            n=pds_cell_string_add (Cout,rep);
+    
+
+            free(rep);
+            if(n==PDS_WRONG)
+            {
+                free(content);
+                pds_cell_string_free(Cout);
+                return NULL;
+            }
+
+
+            rep=(*func)(content);
+            if(rep==NULL)
+            {
+                free(content);
+                pds_cell_string_free(Cout);
+                return NULL;
+            }
+
+            pds_cell_string_add (Cout,rep);
+            pds_cell_string_add (Cout,pat_close);
+
+          
+            free(content);
+            free(rep);
+        }
+        else
+        {
+            pds_cell_string_add (Cout,str_last);
+            break;
+        }
+
+    }
+
+    str_out=pds_cell_string_joint(Cout);
+    pds_cell_string_free(Cout);
+
+    return str_out;
+}
+
+
