@@ -37,22 +37,31 @@ extern "C" {
 
 #include <stdio.h>
 
-#ifndef TRUE
-	#define TRUE 1
-#endif
-
-#ifndef FALSE
-	#define FALSE 0
-#endif
 
 /** \defgroup PdsCellStringGroup Funciones del módulo PdsCellString.
  *
  *  Estas funciones manipulan un arreglo de células con elemento de tipo cadena.
- *  <br>
- *  Funciones.
+ *
+ * <h1>\#include \<pds/pdsdatafunc.h\></h1>
+ *
  * @{
  */
 
+#ifndef PDS_OK
+/*!
+  \def PDS_OK
+  Valor retornado en caso de exito, este es un valor diferente que cero.
+*/
+	#define PDS_OK 1
+#endif
+
+#ifndef PDS_WRONG
+/*!
+  \def PDS_WRONG
+  Valor retornado en caso de fracaso, este valor es igual a cero.
+*/
+	#define PDS_WRONG 0
+#endif
 
 
 /*! \struct PdsCellString
@@ -79,6 +88,7 @@ typedef struct
  *  \brief Crea un arreglo de células de tipo PdsCellString con N elementos 
  *  vacíos (NULL).
  *  \param[in] N Número de elementos de elementos del arreglo de células.
+ *  N puede ser cero.
  *  \return Un puntero a una estructura de tipo PdsCellString.
  *  \ingroup PdsCellStringGroup
  */
@@ -106,7 +116,7 @@ PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin);
  *  \brief Imprime en pantalla los datos del arreglo de células de tipo puntero 
  *  PdsCellString. Escribe un dato por cada linea.
  *  \param[in] C El arreglo de células a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_all_printf(const PdsCellString *C);
@@ -117,7 +127,7 @@ int pds_cell_string_all_printf(const PdsCellString *C);
  *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
  *  \param[in,out] fd El descriptor de fichero sobre el cual escribir.
  *  \param[in] C El arreglo de células a escribir.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C);
@@ -136,7 +146,7 @@ int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C);
  *  O agrega un nuevo registro de memoria.
  *  \param[in,out] C El arreglo de células para agregar datos.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Si string_data==NULL 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si string_data==NULL 
  *  no es considerado error y se finaliza la función sin hacer ningún cambio.
  *  \ingroup PdsCellStringGroup
  */
@@ -153,7 +163,7 @@ int pds_cell_string_add(PdsCellString *C,const char* string_data);
  *  NO LIBERAR Y RESERVAR MEMORIA TAN ALEGREMENTE. ASSI SE GANARIA VELOCIDAD.
  *  \param[in,out] C El arreglo de células a agregar datos.
  *  \param[in] Cin El arreglo de células de donde se leen los datos.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin);
@@ -171,7 +181,7 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin);
  *  \param[in,out] C El arreglo de células a escribir.
  *  \param[in] id Posición en donde escribir el dato.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Retorna FALSE si el id está fuera 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Retorna PDS_WRONG si el id está fuera 
  *  de rango.
  *  \ingroup PdsCellStringGroup
  */
@@ -184,7 +194,7 @@ int pds_cell_string_write(PdsCellString *C,int id,const char* string_data);
  *  \param[in] id La posición a leer.
  *  \param[out] string_data La dirección de la cadena a leer (NO debe liberarse esta 
  *  dirección de memoria).
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_read(const PdsCellString* C,int id,char** string_data);
@@ -195,7 +205,7 @@ int pds_cell_string_read(const PdsCellString* C,int id,char** string_data);
  *
  *  \param[in,out] C El arreglo de células a remover datos.
  *  \param[in] id El id de la célula a remover.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  En caso de error no modifica el contenido de C.
  *  \ingroup PdsCellStringGroup
  */
@@ -210,6 +220,24 @@ int pds_cell_string_remove(PdsCellString *C,int id);
  * @{
  */
 
+/** \fn int pds_cell_string_sort_by_length( PdsCellString *C)
+ *  \brief Ordena de forma alfabetica ascendentemente con los siguientes criterios:
+ *  es mayor quien tienes mas carateres, si son igual numero de caracteres
+ *  entonces es mayor quien tiene  mas orden alfabetico.
+ *  \param[in] C El arreglo de células a ordenar.
+ *  \return Retorna un número menor que cero en caso de error.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_sort_by_length( PdsCellString *C);
+
+/** \fn int pds_cell_string_sort_by_lexicographic_order( PdsCellString *C)
+ *  \brief Ordena de forma lexicografica ascendentemente las celulas.
+ *  \param[in] C El arreglo de células a ordenar.
+ *  \return Retorna un número menor que cero en caso de error.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_sort_by_lexicographic_order( PdsCellString *C);
+
 /** \fn int pds_cell_string_get_ncell(const PdsCellString *C)
  *  \brief Cuenta la cantidad de células incluyendo las vacías.
  *  \param[in] C El arreglo de células a analizar.
@@ -271,7 +299,7 @@ char * pds_cell_string_joint_with_end(const PdsCellString *C,char s);
  *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
  *  \param[in] pathname La dirección de fichero sobre el cual escribir.
  *  \param[in] C El arreglo de células a escribir.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_save(const char* pathname,const PdsCellString *C);
@@ -300,9 +328,9 @@ PdsCellString *pds_cell_string_new_load(const char*filepath);
  *  \param[in,out] C El arreglo de células a remover datos.
  *  \param[in] pattern El patrón de búsqueda.Ejemplo: pattern->data[i] <-- "*.[ch]"
  *  donde se aceptarán "*.c" o "*.h". La función cumple patrones aceptados por fnmatch().
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  En caso de error el contenido de C no es modificado. Si pattern es NULL no 
- *  es considerado error y se retorn TRUE sin hacer nada.
+ *  es considerado error y se retorn PDS_OK sin hacer nada.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern);
@@ -346,7 +374,7 @@ int pds_cell_string_findci(const PdsCellString *C,const char *str);
  *  diferencia mayúsculas y minúsculas.
  *  \param[in,out] C El arreglo de células para agregar datos.
  *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Si string_data==NULL 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si string_data==NULL 
  *  no es considerado error y se finaliza la función sin hacer ningún cambio.
  *  \ingroup PdsCellStringGroup
  */
@@ -357,8 +385,8 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data);
  *  \brief Procura todas las células con cadenas igual a str y las remueve.
  *  \param[in,out] C El arreglo de células a analizar.
  *  \param[in] str La cadena a buscar.
- *  \return Retorna TRUE si todo fue bien o FALSE si no. Si C o str son nulos
- *  entonces retorna FALSE sin hacer nada sobre C.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no. Si C o str son nulos
+ *  entonces retorna PDS_WRONG sin hacer nada sobre C.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_find_and_remove(PdsCellString *C,const char *str);
@@ -369,8 +397,8 @@ int pds_cell_string_find_and_remove(PdsCellString *C,const char *str);
  *  \param[in,out] C El arreglo de células a analizar.
  *  La función es case-insensitive.
  *  \param[in] str La cadena a buscar.
- *  \return Retorna TRUE si todo fue bien o FALSE si no. Si C o str son nulos
- *  entonces retorna FALSE sin hacer nada sobre C.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no. Si C o str son nulos
+ *  entonces retorna PDS_WRONG sin hacer nada sobre C.
  *  \ingroup PdsCellStringGroup
  */
 int pds_cell_string_findci_and_remove(PdsCellString *C,const char *str);
