@@ -39,21 +39,30 @@ extern "C" {
 #include <stdio.h>
 #include <pds/pdscstring.h>
 
-#ifndef TRUE
-	#define TRUE 1
-#endif
-
-#ifndef FALSE
-	#define FALSE 0
-#endif
 
 /** \defgroup PdsFilesFuncGroup Funciones del módulo PdsFilesFunc.
  *
- *  <br>
- *  Funciones.
+ * <h1>\#include \<pds/pdsdatafunc.h\></h1>
+ *
  * @{
  */
 
+#ifndef PDS_OK
+/*!
+  \def PDS_OK
+  Valor retornado en caso de exito, este es un valor diferente que cero.
+*/
+	#define PDS_OK 1
+#endif
+
+#ifndef PDS_WRONG
+/*!
+  \def PDS_WRONG
+  Valor retornado en caso de fracaso, este valor es igual a cero.
+*/
+	#define PDS_WRONG 0
+#endif
+
 
 /*! \enum ArqType
  *  \brief Una union de tipo ArqType.
@@ -61,7 +70,6 @@ extern "C" {
  *  <br>
  *
  *  \ingroup PdsFilesFuncGroup
- *  \author Fernando Pujaico Rivera
  */
 typedef enum{
     TYPE_FILE, /**< Buscando ficheros excluyendo los simbólicos*/
@@ -125,60 +133,150 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
  * @{
  */
 
-/** \fn char *pds_get_filedata_string(const char *pathname,const char* pattern)
+
+
+/** \fn char *pds_get_filedata_string(const char *filepath,const char* pattern, const char* reject,const char* default_value)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el texto despues de el primer patrón pattern encontrado.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  el texto despues del primer patrón pattern encontrado.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer la cadena "Cadena de texto" usaremos:
+ * \code{.c}
+ * DATA=pds_get_filedata_string("mydata.ini","MY_SECOND_DATA","= ","valor por defecto");
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna NULL.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna NULL.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  Si la variable default_value es usada entonces reject no es aplicado sobre el dato retornado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia.
+ *  Si default_value==NULL y no es encontrado ningun dato o este esta vacio entonces
+ *  NULL es retornando.
  *  \return Retorna una nueva cadena de texto con el dato encontrado,
- *  una cadena vacia si no existe ningun dato o NULL
- *  si se encontró algun error.
+ *  o NULL si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-char *pds_get_filedata_string(const char *pathname,const char* pattern);
+char *pds_get_filedata_string(const char *filepath,const char* pattern, const char* reject,const char* default_value);
 
-/** \fn int pds_get_filedata_int(const char *pathname,const char* pattern)
+/** \fn int pds_get_filedata_int(const char *filepath,const char* pattern, const char* reject,int default_value)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el valor int despues de el primer patrón pattern encontrado.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  el valor entero despues del primer patrón pattern encontrado.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
- *  \return Retorna el valor en int con el dato encontrado.
- *  En caso de error es retornado zero.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer el valor 1000 usaremos:
+ * \code{.c}
+ * DATA=pds_get_filedata_int("mydata.ini","MY_FIRST_DATA","= ",-1);
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna default_value.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna default_value.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia o en caso de algun error.
+ *  \return Retorna el dato encontrado, o default_value si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-int pds_get_filedata_int(const char *pathname,const char* pattern);
+int pds_get_filedata_int(const char *filepath,const char* pattern, const char* reject,int default_value);
 
-/** \fn int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+
+/** \fn int pds_get_filedata_strcmp(const char *filepath,const char* pattern,const char* reject,const char* dat)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  TRUE si el valor despues de el primer patrón pattern encontrado es dat.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  PDS_OK si el valor despues de el primer patrón pattern encontrado es dat.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
- *  \param[in] dat Dato a comparar.
- *  \return Retorna TRUE si el valor dat es encontrado despues del primer 
- *  patrón pattern. En caso de error es retornado FALSE.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para comparar el valor TRUE usaremos:
+ * \code{.c}
+ * d=pds_get_filedata_strcmp("mydata.ini","MY_THIRD_DATA","= ",TRUE);
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna PDS_WRONG.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna PDS_WRONG.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  \param[in] dat Es dato a comparar. Si dat==NULL se retornará PDS_WRONG.
+ *  no es encontrado, o si el valor encontrado es una cadena vacia o en caso de algun error.
+ *  \return Retorna PDS_OK si el valor dat es encontrado despues del primer 
+ *  patrón pattern. En caso de error es retornado PDS_WRONG.
  *  \ingroup PdsFilesFuncGroup
  */
-int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat);
+int pds_get_filedata_strcmp(const char *filepath,const char* pattern,const char* reject,const char* dat);
 
 
-/** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
+/** \fn PdsCellString *pds_get_filedata_cell_string(const char *filepath,const char* pattern,const char *reject,const char *default_value, const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado, pero estos datos son
  *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
- *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
- *  de linea final.
+ *  <ul>
+ *  <li>Es desconsiderado al final de cada linea el salto de linea. </li>
+ *  <li>Son desconsiderados al inicio de cada linea los espacios y tabuladores. </li>
+ *  <li>Son desconsiderados al final del dato los espacios y tabuladores. </li>
+ *  <li>Son desconsideradas al inicio del dato qualquier caracter en reject. </li>
+ *  </ul>
  *
- *  \param[in] pathname Fichero de texto a analizar.
- *  \param[in] pattern Patrón a buscar.
+ *  Por ejemplo para un archivo mydata.ini con
+ * \code{.c}
+ *  MY_FIRST_DATA  = 1000
+ *  MY_SECOND_DATA = Cadena de texto
+ *  MY_THIRD_DATA  = TRUE
+ *  MY_FOURTH_DATA = dat1, dat2  , dat3
+ * \endcode
+ *
+ *  Para leer llos datos "dat1, dat2  , dat3" usaremos:
+ * \code{.c}
+ * Cell=pds_get_filedata_cell_string("mydata.ini","MY_FOURTH_DATA","= ","valor por defecto",";,");
+ * \endcode
+ *
+ *  \param[in] filepath Fichero de texto a analizar. Si filepath==NULL se retorna NULL.
+ *  \param[in] pattern Patrón a buscar. Si pattern==NULL se retorna NULL.
+ *  \param[in] reject Caracteres a eliminar al inicio del dato encontrado.
+ *  Si reject==NULL o vacio, no se elimina ningun caracter al inicio del dato encontrado.
+ *  Si la variable default_value es usada entonces reject no es aplicado sobre el dato retornado.
+ *  \param[in] default_value Es el valor por defecto que será retornado si pattern
+ *  no es encontrado, o si el valor encontrado es una cadena vacia.
+ *  Si default_value==NULL y no es encontrado ningun dato o este esta vacio entonces
+ *  NULL es retornando.
  *  \param[in] separator Separador de texto. Si separator es igual a NULL o vacia la 
  *  función retorna la cadena sem dividir.
  *  \return Retorna una nueva estructurs PdsCellString con los datos encontrado.
@@ -186,7 +284,10 @@ int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char*
  *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
-PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator);
+PdsCellString *pds_get_filedata_cell_string(const char *filepath,const char* pattern,
+                                            const char *reject,const char *default_value, 
+                                            const char *separator);
+
 
 //@}
 
@@ -279,7 +380,7 @@ PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char
  *   filepath.
  *
  *  \param[in] filepath Ruta del fichero a analizar. 
- *  \return Retorna TRUE si todo fue bien o FALSE en el caso contrario.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG en el caso contrario.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_cat(const char* filepath);
@@ -472,20 +573,20 @@ char *pds_read_line(FILE *fd);
  */
 
 /** \fn int pds_is_file(const char *path)
- *  \brief TRUE si es un fichero (simbólico o real) o FALSE si no.
+ *  \brief PDS_OK si es un fichero (simbólico o real) o PDS_WRONG si no.
  *
  *  \param[in] path Dirección de fichero a testar.
- *  \return Retorna TRUE is es un fichero o FALSE si no.
+ *  \return Retorna PDS_OK is es un fichero o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_is_file(const char *path);
 
 
 /** \fn int pds_is_dir(const char *path)
- *  \brief TRUE is es un directorio (simbólico o real) o FALSE si no.
+ *  \brief PDS_OK is es un directorio (simbólico o real) o PDS_WRONG si no.
  *
  *  \param[in] path Dirección de directorio a testar.
- *  \return Retorna TRUE is es un directorio o FALSE si no.
+ *  \return Retorna PDS_OK is es un directorio o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_is_dir(const char *path);
@@ -513,22 +614,22 @@ long pds_get_number_of_chars(const char *path);
 
 
 /** \fn int pds_exist_file(const char *path)
- *  \brief Retorna TRUE si path es un fichero real o simbólico (no un directorio) 
+ *  \brief Retorna PDS_OK si path es un fichero real o simbólico (no un directorio) 
  *  y es accesible.
  *
  *  \param[in] path Dirección de fichero a testar.
- *  \return Retorna TRUE si el archivo existe o FALSE si no.
+ *  \return Retorna PDS_OK si el archivo existe o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_exist_file(const char *path);
 
 
 /** \fn int pds_archive_is_accessible(const char *path)
- *  \brief Retorna TRUE si el archivo simbólico o real (Directorio o fichero) 
+ *  \brief Retorna PDS_OK si el archivo simbólico o real (Directorio o fichero) 
  *  es accesible.
  *
  *  \param[in] path Dirección de archivo a testar.
- *  \return Retorna TRUE si el archivo existe o FALSE si no.
+ *  \return Retorna PDS_OK si el archivo existe o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_archive_is_accessible(const char *path);
@@ -554,7 +655,7 @@ int pds_archive_is_accessible(const char *path);
  *  \param[in] filename_in Archivo de entrada donde se realizará la búsqueda.
  *  \param[in] pat Patron a buscar.
  *  \param[in] rep Patron a de remplazo.
- *  \return Retorna TRUE si todo fue bien o FALSE si no.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_file_pattern_replacement(const char *filename_out,const char *filename_in,const char *pat,const char *rep);
@@ -583,7 +684,9 @@ replace=func(content);
 \endcode
  *  este será remplazado por el contenido de la cadena replace, luego la cadena 
  *  replace será liberada internamente con free(replace).
- *  \return Retorna TRUE si todo fue bien o FALSE si no.
+ *  Si la funcion func retorna NULL, la escritura en filename_out es detenida y
+ *  se retorna PDS_WRONG.
+ *  \return Retorna PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsFilesFuncGroup
  */
 int pds_file_content_replacement(   const char *filename_out,const char *filename_in,
