@@ -50,9 +50,10 @@ gcc -o testpdslstring testpdslstring.c -lpdsdatafunc
 int main(int argc, char* argv[])
 {
     PdsListString *Lall=NULL;
+    int Nnodes,N;
     
     // Creating a new list string.
-    Lall=pds_list_string_new();
+    Lall=pds_list_string_new_with_string("0st text string.");
     if(Lall==NULL) return EXIT_FAILURE;
     
     
@@ -62,12 +63,31 @@ int main(int argc, char* argv[])
     pds_list_string_push(&Lall,"3dh text string.");
     pds_list_string_push(&Lall,"4th text string.");
     
+    // Show the number of nodes and no null strings
+    Nnodes=pds_list_string_get_number_of_nodes(Lall);
+    printf("Nnodes=%d\n",Nnodes);
+    
+    
+    printf("\n");
     
     // Printing values of the cell string.
-    printf("\nPdsListString *Lall=\n");
+    printf("\n<<<< Lall >>>>>\n");
     pds_list_string_all_printf(Lall);
     
     
+    do{
+        pds_list_string_delete_top_node(&Lall);
+        
+        
+        // Printing values of the cell string.
+        printf("\n<<<< Lall >>>>>\n");
+        pds_list_string_all_printf(Lall);
+        
+
+        N=pds_list_string_get_number_of_no_null_nodes(Lall);
+        printf("N=%d\n",N);
+    }while(N>0);
+    
     return EXIT_SUCCESS;
 }
 
